@@ -12,6 +12,8 @@ from itertools import groupby
 from .index_array_iterator import IMCOMPLETE_LAST_BATCH_MODE
 try:
     import elasticdeform as ed
+    from elasticdeform.deform_grid import _normalize_axis_list
+    from elasticdeform.deform_grid import _normalize_inputs
 except ImportError:
     ed = None
 
@@ -409,11 +411,23 @@ class MultiChannelIterator(IndexArrayIterator):
         for chan_idx in channels:
             batch_by_channel[chan_idx] = self._get_batches_of_transformed_samples_by_channel(index_ds, index_array, chan_idx, channels[0], aug_param_array, perform_augmentation=perform_augmentation)
 
+        if perform_elasticdeform or perform_tiling: ## elastic deform do not support float16 type -> temporarily convert to float32
+            channels = [c for c in batch_by_channel.keys() if c>=0]
+            converted_from_float16=[]
+            for c in channels:
+                if batch_by_channel[c].dtype == np.float16:
+                    batch_by_channel[c] = batch_by_channel[c].astype('float32')
+                    converted_from_float16.append(c)
+
         if perform_elasticdeform:
             self._apply_elasticdeform(batch_by_channel)
         if perform_tiling:
             self._apply_tiling(batch_by_channel)
 
+        if perform_elasticdeform or perform_tiling:
+            for c in converted_from_float16:
+                batch_by_channel[c] = batch_by_channel[c].astype('float16')
+
         if self.channels_postprocessing_function is not None:
             self.channels_postprocessing_function(batch_by_channel)
 
@@ -432,10 +446,24 @@ class MultiChannelIterator(IndexArrayIterator):
             mode = self.elasticdeform_parameters.pop('mode', 'mirror')
             image_shape = batch_by_channel[channels[0]].shape[1:-1]
             grid_spacing = ensure_multiplicity(len(image_shape), self.elasticdeform_parameters.pop('grid_spacing', 15))
-            points = self.elasticdeform_parameters.pop('points', [max(3, s//gs) for s, gs in zip(image_shape, grid_spacing)])
-            sigma = self.elasticdeform_parameters.pop('sigma', np.min([s/p for s, p in zip(image_shape, points)]))
+            points = self.elasticdeform_parameters.pop('points', [max(5, 1+s//gs) for s, gs in zip(image_shape, grid_spacing)])
+            sigma_factor = self.elasticdeform_parameters.pop('sigma_factor', 1./8)
+            sigma = self.elasticdeform_parameters.pop('sigma', np.min([sigma_factor*s/(p-1) for s, p in zip(image_shape, points)]))
             batches = [batch_by_channel[chan_idx] for chan_idx in channels]
-            batches = ed.deform_random_grid(batches, order = order, sigma=sigma, mode=mode, axis=axis, **self.elasticdeform_parameters)
+
+            Xs = _normalize_inputs(batches)
+            axis, deform_shape = _normalize_axis_list(axis, Xs)
+
+            if not isinstance(points, (list, tuple)):
+                points = [points] * len(deform_shape)
+
+            displacement = np.random.randn(len(deform_shape), *points) * sigma
+            # set zero displacement at edges to avoid out-of-bounds artifacts
+            displacement[:, [0,-1], :] = 0
+            displacement[:, :, [0,-1]] = 0
+
+            batches = ed.deform_grid(batches, displacement, order=order, mode=mode, axis=axis, **self.elasticdeform_parameters)
+
             for i, chan_idx in enumerate(channels):
                 batch_by_channel[chan_idx] = batches[i]
 
@@ -726,7 +754,7 @@ class MultiChannelIterator(IndexArrayIterator):
             # pick indices for each group
             if self.allowed_indexes is None:
                 indices_per_group = [np.random.randint(low=self.grp_off[i], high=self.grp_len[i], size=int((self.grp_len[i] - self.grp_off[i])*self.group_proportion[i]+0.5) ) for i in range(len(self.group_map_paths))]
-                index_a = flatten_list(indices_per_group)
+                index_a = np.concatenate(indices_per_group)
             else:
                 index_array = np.copy(self.allowed_indexes) # index within group
                 index_grp = self._get_grp_idx(index_array) # group index
